@@ -89,7 +89,7 @@ cannot find what you are looking for, try here.
 =head1 DATA TYPES
 
 PDL comes with support for most native numeric data types available in C.
-2.027 added support for C99 complex numbers.  See L<PDL::Complex>,
+2.027 added support for C99 complex numbers.  See
 L<PDL::Core>, L<PDL::Ops> and L<PDL::Math> for details on usage and
 behaviour.
 
@@ -156,7 +156,7 @@ start-up modules.
 =cut
 
 # set the version:
-our $VERSION = '2.055';
+our $VERSION = '2.056';
 
 # Main loader of standard PDL package
 
